#!/usr/bin/env python3
# Copyright (C) 2017 - mod_auth_gssapi contributors, see COPYING for license.

import sys

import requests
from requests_gssapi import HTTPKerberosAuth, OPTIONAL # noqa


if __name__ == '__main__':
    sess = requests.Session()
    url = 'http://{}/{}/'.format(sys.argv[1], sys.argv[2])
    r = sess.get(url, auth=HTTPKerberosAuth(delegate=True))
    if r.status_code != 200:
        raise ValueError('Hostname acceptor ({}) failed'.format(sys.argv[2]))



#!/usr/bin/env python3
# Copyright (C) 2015 - mod_auth_gssapi contributors, see COPYING for license.

import os

import requests


if __name__ == '__main__':
    s = requests.Session()

    url = 'http://%s:%s@%s/basic_auth_krb5/' % \
          (os.environ['MAG_USER_NAME'],
           os.environ['MAG_USER_PASSWORD'],
           os.environ['NSS_WRAPPER_HOSTNAME'])
    r = s.get(url)
    if r.status_code != 200:
        raise ValueError('Basic Auth Failed')

    url = 'http://%s:%s@%s/basic_auth_krb5/' % \
          (os.environ['MAG_USER_NAME_2'],
           os.environ['MAG_USER_PASSWORD_2'],
           os.environ['NSS_WRAPPER_HOSTNAME'])
    r2 = s.get(url)
    if r2.status_code != 200:
        raise ValueError('Basic Auth failed')

    if r.text == r2.text:
        raise ValueError('Basic Auth fatal error')



#!/usr/bin/env python3
# Copyright (C) 2020 - mod_auth_gssapi contributors, see COPYING for license.

import os
import subprocess
import sys

import gssapi

import requests

from requests_gssapi import HTTPSPNEGOAuth


def use_requests(auth):
    sess = requests.Session()
    url = 'http://%s/gss_localname/' % os.environ['NSS_WRAPPER_HOSTNAME']

    r = sess.get(url, auth=auth)
    if r.status_code != 200:
        raise ValueError('Localname failed')

    if r.text.rstrip() != os.environ['MAG_REMOTE_USER']:
        raise ValueError('Localname, REMOTE_USER check failed')


def use_curl():
    url = 'http://%s/gss_localname/' % os.environ['NSS_WRAPPER_HOSTNAME']
    curl = subprocess.Popen(["curl", "--negotiate", "-u:", url],
                            stdout=subprocess.PIPE)
    curl.wait()
    if curl.returncode != 0:
        raise ValueError('Localname failed')

    line = curl.stdout.read().strip(b' \t\n\r').decode('utf-8')
    if line != os.environ['MAG_REMOTE_USER']:
        raise ValueError('Localname, REMOTE_USER check failed (%s != %s)' % (
                         line, os.environ['MAG_REMOTE_USER']))


if __name__ == '__main__':
    mech_name = None
    if len(sys.argv) > 1:
        mech_name = sys.argv[1]

    mech = None
    if mech_name is not None:
        mech = gssapi.mechs.Mechanism.from_sasl_name(mech_name)

    try:
        auth = HTTPSPNEGOAuth(mech=mech)
        use_requests(auth)
    except TypeError:
        # odler version of requests that does not support mechs
        if mech_name == 'SPNEGO':
            use_curl()
        elif mech_name == 'GS2-KRB5':
            # older request versions use krb5 as the mech by default
            auth = HTTPSPNEGOAuth()
            use_requests(auth)
        else:
            sys.exit(42)  # SKIP



#!/usr/bin/env python3
# Copyright (C) 2020 - mod_auth_gssapi contributors, see COPYING for license.

import os
import time

import requests
from requests.auth import HTTPBasicAuth


if __name__ == '__main__':
    s = requests.Session()
    url = 'http://{}/basic_auth_timeout/auth/'.format(
            os.environ['NSS_WRAPPER_HOSTNAME']
    )
    url2 = 'http://{}/basic_auth_timeout/session/'.format(
            os.environ['NSS_WRAPPER_HOSTNAME']
    )

    r = s.get(url, auth=HTTPBasicAuth(os.environ['TIMEOUT_USER'],
                                      os.environ['MAG_USER_PASSWORD']))
    if r.status_code != 200:
        raise ValueError('Basic Auth Failed')

    time.sleep(301)
    r = s.get(url2)
    if r.status_code != 200:
        raise ValueError('Session Auth Failed')

    time.sleep(401)

    r = s.get(url2)
    if r.status_code == 200:
        raise ValueError('Timeout check Failed')



#!/usr/bin/env python3
# Copyright (C) 2015 - mod_auth_gssapi contributors, see COPYING for license.

import os
import requests
from requests.auth import HTTPBasicAuth


if __name__ == '__main__':
    url = 'http://%s/mech_name/mech.html' % os.environ['NSS_WRAPPER_HOSTNAME']
    r = requests.get(url, auth=HTTPBasicAuth(os.environ['MAG_USER_NAME'],
                                             os.environ['MAG_USER_PASSWORD']))
    if r.status_code != 200:
        raise ValueError('Basic Auth Failed')

    if r.text.rstrip() != 'Basic/krb5':
        raise ValueError(
            'GSS_MECH check failed, expected Basic/krb5, got "%s"' %
            r.text.rstrip())
